/*************************************************************************
  Overview:
  
  This sample program drives fluorecent ballast using 16-bit PWMs for PFC
  control and inverter outputs. A comparator detects zero-current
  detection for PFC control using interlocking function with 16-bit PWM.
  ADC channels are set to detect PFC-output voltage, lamp detection,
  AC supply voltage and a volume for lamp dimming.
  
  This sample program can be evaluated with a 78K0/IB2 Fluorecent Ballast
  Evaluation Board (EZ-BLST-003).
  
    <Pin Assign>
    P00:		I	(not used)
    P01:		I	(not used)
    P02:		I	(not used)
    
	P20/ANI0:	I	DC output voltage detection
	P21:		I	(not used)
	P22:		I	(not used)
	P23/CMP2+:	I	Zero current detection
	P24/ANI4:	I	Lamp detection
	P25:		I	(not used)
	P26/ANI6:	I	AC supply voltage detection
	P27:		I	(not used)
	
	P30:		I	(not used)
	P31/TOX00:	O	PFC output
	P32:		I	(not used)
	P33/TOX10:	O	Low-side inverter output
	P34/TOX11:	O	High-side inverter output
	P35:		I	(not used)
	P36:		I	(not used)
	P37:		I	(not used)
	
	P60:		I	(not used)
	P61:		I	(not used)
	
	P70/ANI8:	I	Volume input for dimming control
    
*************************************************************************/

/************************************************************************/
/*																		*/
/*	System		: 78K0/IB2 Fluorecent Ballast Evaluation Board			*/
/*				  (EZ-BLST-003)											*/
/*																		*/
/*	Function	: Main loop												*/
/*																		*/
/*	CPU			: uPD78F0756											*/
/*																		*/
/*	Last Update	: 2009/08/10(MON)										*/
/*																		*/
/*	File name	: main.c												*/
/*																		*/
/************************************************************************/
#pragma	SFR
#pragma	EI

/*========================================================================
	External function definition
========================================================================*/
extern void fn_ini_ad_variables(void);		/* Initialize the A/D conversion variables */
extern void fn_ini_status_variables(void);	/* Initialize the lamp status variables */
extern void fn_start_ad(void);				/* Start A/D conversion */
extern void fn_accumulate_ad(void);			/* Accumulate and add A/D value */
extern void fn_average_ad(void);			/* Average A/D value */
extern void fn_check_request(void);			/* Check dimming request */
extern void fn_detect_fault(void);			/* Fault detection for emergency stop */
extern void fn_control_vdc(void);			/* Control DC output voltage */
extern void fn_control_dim(void);			/* Control dimming process */

/*************************************************************************
**	
**  function name:
**  	main
**
**	function:
**		1. Initialize the variables for A/D conversion and the lamp status.
**		2. Start A/D conversion and system timer operation.
**		3. Dim fluorecent lamp due to volume input.
**		This function is called after startup rootin.
**
**  Argument:
**  	void
**
**  Returned value:
**  	void
**
*************************************************************************/
void main(void)
{
	fn_ini_ad_variables();		/* Initialize the A/D conversion variables */
	fn_ini_status_variables();	/* Initialize the lamp status variables */
	
	ADCE = 1;					/* Enables A/D voltage comparator operation */
	fn_start_ad();				/* Start A/D conversion */
	
	TMHE1 = 1;					/* Start TMH1 for system timer */
	
	EI();						/* Enables interrupt */
	
	while (1)
	{
		if (ADIF)				/* A/D conversion has been completed */
		{
			fn_accumulate_ad();		/* Accumulate A/D value */
		}
		
		if (TMIFH1)				/* 10ms interval process */
		{
			TMIFH1 = 0;				/* Clear 10ms interval flag */
			fn_average_ad();		/* Stop A/D conversion and average A/D value */
			fn_check_request();		/* Check dimming request */
			fn_detect_fault();		/* Fault detection for emergency stop */
			fn_control_vdc();		/* Control DC output voltage */
			fn_control_dim();		/* Control Dimming process */
			fn_start_ad();			/* Start A/D conversion */
		}
	}
}
