;***********************************************************************;
;									;
;	System		: 78K0/IB2 Fluorecent Ballast Evaluation Board	;
;			  (EZ-BLST-003)					;
;									;
;	Function	: Option byte setting				;
;									;
;	CPU		: uPD78F0756					;
;									;
;	Last Update	: 2009/08/10(MON)				;
;									;
;	File name	: option.asm					;
;									;
;***********************************************************************;
;
;------------------------------------------------------------------------
;	Option Byte
;------------------------------------------------------------------------
OPTB1	EQU 00000000B
;	    |||||||+-- LSROSC
;	    |||||||	Internal low-speed oscillator operation
;	    |||||||	0 : Can be stopped by software 
;	    |||||||	1 : Cannot be stopped
;	    |||||||
;	    ||||+++--- WDCS2-0
;	    ||||	Watchdog timer overflow time
;	    ||||	000 : 2^7/fIL (3.88 ms)
;	    ||||	001 : 2^8/fIL (7.76 ms)
;	    ||||	010 : 2^9/fIL (15.52 ms)
;	    ||||	011 : 2^10/fIL (31.03 ms)
;	    ||||	100 : 2^12/fIL (124.12 ms)
;	    ||||	101 : 2^14/fIL (496.48 ms)
;	    ||||	110 : 2^15/fIL (992.97 ms)
;	    ||||	111 : 2^17/fIL (3.97 s)
;	    ||||
;	    |||+------ WDTON
;	    |||		Operation control of watchdog timer counter
;	    |++------- WINDOW1-0
;	    |		Watchdog timer window open period
;	    |		00 : 25%
;	    |		01 : 50%
;	    |		10 : 75%
;	    |		11 : 100%
;	    |
;	    +--------- must be 0

OPTB2	EQU 00000000B
;	    |||||||+-- LVISTART
;	    |||||||	LVI default start operation control
;	    |||||||	0 : LVI is OFF by default upon reset release
;	    |||||||	1 : LVI is ON by default upon reset release
;	    |||||||
;	    +++++++--- must be 0

OPTB3	EQU 00000001B
;	    |||||||+-- R4M8MSEL
;	    |||||||	Internal high-speed oscillation clock frequency selection
;	    |||||||	0 : 8 MHz (TYP.)
;	    |||||||	1 : 4 MHz (TYP.)
;	    |||||||
;	    +++++++--- must be 0

OPTB4	EQU 00011110B
;	    |||||||+-- OCDONB
;	    |||||||	Transition of on-chip debug mode
;	    |||||||	0 : Not shifting to on-chip debug mode after reset release
;	    |||||||	1 : Shifting to on-chip debug mode after reset release
;	    |||||||
;	    ||||||+--- OCDPSEL
;	    ||||||	Pin selection used during on-chip debugging
;	    ||||||	0 : TOOLC1/P31, TOOLD1/P32
;	    ||||||	1 : TOOLC0/X1, TOOLD0/X2
;	    ||||||
;	    ||||++---- must be 1
;	    ||||
;	    |||+------ OCDCKSTOP
;	    |||		Internal high-speed oscillator operation control after execution
;	    |||		of the STOP instruction in on-chip debug mode
;	    |||		0 : Internal high-speed oscillator operation continues
;	    |||		1 : Internal high-speed oscillator operation stops
;	    |||
;	    +++------- must be 0

OPTB5	EQU 00000010B
;	    ||||||++-- OCDEN1-0
;	    ||||||	On-chip debug operation control
;	    ||||||	00 : Operation disabled
;	    ||||||	01 : Setting prohibited
;	    ||||||	10 : Operation enabled. Does not erase data of the flash memory
;	    ||||||	     in case authentication of the on-chip debug security ID fails.
;	    ||||||	11 : Operation enabled. Erases data of the flash memory in case
;	    ||||||	     authentication of theon-chip debug security ID fails.
;	    ||||||
;	    ++++++---- must be 0

OPT0 CSEG AT 0080H
	DB OPTB1	; Switch OFF WTD
	DB OPTB2	; Switch OFF LVI
	DB OPTB3	; Internal high-speed oscillation clock frequency 4MHziTYP.j
	DB OPTB4	; Internal high-speed oscillator operation stops after STOP instruction in OCD mode.
;			    Use TOOLC0/X1, TOOLD0/X2 for OCD
;			    Not shifting to on-chip debug mode after reset release
	DB OPTB5	; Operation enabled. Does not erase data of the flash memory in case authentication
;			  of the on-chip debug security ID fails.


OPT1 CSEG AT 1080H
	DB OPTB1	; Switch OFF WTD
	DB OPTB2	; Switch OFF LVI
	DB OPTB3	; Internal high-speed oscillation clock frequency 4MHziTYP.j
	DB OPTB4	; Internal high-speed oscillator operation stops after STOP instruction in OCD mode.
;			    Use TOOLC0/X1, TOOLD0/X2 for OCD
;			    Not shifting to on-chip debug mode after reset release
	DB OPTB5	; Operation enabled. Does not erase data of the flash memory in case authentication
;			  of the on-chip debug security ID fails.

END
